@@ -1,5 +1,5 @@
 """
-Read different data sources and combine them.
+Utility module for reading different data sources.
 
 Data sources are specified at README.md
 """
@@ -7,7 +7,8 @@ Data sources are specified at README.md
 
 import os
 from enum import Enum
-from functools import lru_cache
+from pathlib import Path
+from typing import Union
 
 import pandas as pd
 
@@ -38,7 +39,6 @@ class ShapeFiles(Enum):
     IHO_SEA_AREAS: os.path = os.path.join("IHO Sea Areas", "World_Seas_IHO_v3.shp")
 
 
-@lru_cache(None)
 def read_shapefile(shape_name: ShapeFiles) -> gpd.GeoDataFrame:
     """
     Read shapefiles.
@@ -64,7 +64,6 @@ def read_shapefile(shape_name: ShapeFiles) -> gpd.GeoDataFrame:
     return gdf
 
 
-@lru_cache(None)
 def read_gisd_worms_link() -> pd.DataFrame:
     """
     Reads GISD and WoRMS qualitative distribution linked to MEOW.
@@ -82,12 +81,11 @@ def read_gisd_worms_link() -> pd.DataFrame:
         skiprows=5,
         engine="openpyxl",
     )
-    df["ECO_CODE_X"] = df["ECO_CODE_X"].str.replace(".", ",")
+    df["ECO_CODE_X"] = df["ECO_CODE_X"].str.replace(".", ",", regex=False)
 
     return df
 
 
-@lru_cache(None)
 def read_natcon() -> pd.DataFrame:
     """
     Reads NatCon dataset.
@@ -100,26 +98,34 @@ def read_natcon() -> pd.DataFrame:
     df = pd.read_csv(
         os.path.join(data_path(), "NatConAddAphiaID_FV.csv"),
     )
-    df = df.dropna(subset=['aphiaID'])
+    df = df.dropna(subset=["aphiaID"])
     return df
 
 
-@lru_cache(None)
-def read_gisd() -> pd.DataFrame:
+def read_gisd(gisd_file: Path) -> pd.DataFrame:
     """
     Reads GISD dataset.
 
+    Parameters
+    ----------
+    gisd_file: pathlib.Path
+        Location of the JSON file containing the gisd data
+
     Returns
     -------
     pd.DataFrame
         GISD data
     """
-    df = pd.read_json(os.path.join(data_path(), "gisd.json"))
+    try:
+        df = pd.read_json(gisd_file)
+    except ValueError as e:
+        raise ValueError(f"Error reading the gisd data from {gisd_file} : {e}")
+
+    df.rename(columns={"Species": "species"}, inplace=True)
 
     return df
 
 
-@lru_cache(None)
 def eco_mrgid_link() -> pd.DataFrame:
     """
     Reads ECO regions code from MEOW merged with other shapefiles.
@@ -131,25 +137,34 @@ def eco_mrgid_link() -> pd.DataFrame:
         eco-region code linked to MRGID
     """
     df = pd.read_hdf(os.path.join(data_path(), "eco_mrgid.h5"))
-    df["MRGID"] = df["MRGID"].astype("int64")
+    df.loc[:, "MRGID"] = df["MRGID"].astype("int64")
 
     return df
 
 
-@lru_cache(None)
-def read_taxonomy() -> pd.DataFrame:
+def read_redlist(redlist_file: Union[str, Path]) -> pd.DataFrame:
     """
-    Reads taxonomy data which describes species affected by invasive species.
+    Reads redlist data which describes species affected by invasive species.
+
+    Note
+    ----
+    Depends on redlist data from IUCN which needs to be downloaded manually
+    from https://www.iucnredlist.org/search .  See also the documentation
+    at https://marinvaders.gitlab.io/marinvaders/iucn_data/
+
+
+    Parameters
+    -----------
+    redlist_file: str or pathlib.Path
+        Manually downloaded search results from IUCN (assessment.csv)
 
     Returns
     -------
     Pandas DataFrame
         Affected species
     """
+    df = pd.read_csv(redlist_file, usecols=["scientificName"]).rename(
+        columns={"scientificName": "species"}
+    )
 
-    # TODO: what is taxonomy doing? Ask Francesca? Independent of Eco-region
-    df = pd.read_csv(os.path.join(data_path(), "taxonomy.csv"))
-    df = df[["scientificName"]]
-    df["species"] = df["scientificName"]
-    df.drop(["scientificName"], axis=1, inplace=True)
     return df
