@@ -9,13 +9,13 @@ import pandas as pd
 
 sys.path.append("..")
 
-import marinvaders.marinelife as ml  # noqa: E402
+import marinvaders.main as ml  # noqa: E402
 import marinvaders.readers as readers  # noqa: E402
 
 
 def test_ecoregions():
     """
-    test existance and fields of ecoregion
+    test existence and fields of ecoregion
     """
     marine_ecoregions = ml.marine_ecoregions()
     assert len(marine_ecoregions) > 0
@@ -34,10 +34,10 @@ def test_get_obis_raise_error():
     get_obis returns error when neither aphiaID or eco_code is specified
     """
     with pytest.raises(ValueError):
-        ml.get_obis()
+        ml._get_obis()
 
     with pytest.raises(NotImplementedError):
-        ml.get_obis(eco_code=1, aphia_id=1)
+        ml._get_obis(eco_code=1, aphia_id=1)
 
 
 def test_species_class():
@@ -49,36 +49,51 @@ def test_species_class():
     """
     ds = ml.Species("urn:lsid:marinespecies.org:taxname:145634")
     assert ds.aphia_id == 145634
-    assert len(ds.obis) > 0
-    assert isinstance(ds.obis, pd.DataFrame)
+    assert len(ds._obis) > 0
+    assert isinstance(ds._obis, pd.DataFrame)
     assert "Hawaii" in ds.reported_as_alien.ECOREGION.values
+    assert len(ds.reported_as_alien) < len(ds.all_occurrences)
+    assert len(set(ds.all_occurrences[
+            ds.all_occurrences.establishmentMeans == "Alien"
+        ].ECO_CODE).symmetric_difference(
+        set(ds.reported_as_alien.ECO_CODE))) == 0
 
 
 def test_marine_life_class():
     """
     test instance of MarineLife object for specific eco code
     """
-    marinelife = ml.MarineLife(20194)
-    assert marinelife.eco_code == 20194
+    cocos_code = 20169
+    cocos = ml.MarineLife(eco_code=cocos_code)
+    # there should be alien species
+    assert cocos.alien_species.iloc[0, :].species in cocos.all_species.species.values
+    assert len(cocos.alien_species) < len(cocos.all_species)
+
+
+def test_big_region_obis_api():
+    """
+    the obis API calls has issue with large regions.
+    It needs special code and this test is to make
+    sure all big regions will run properly.
+    Here we use High Arctic Archipelago (code 25010)
+    """
+    arctic = ml.MarineLife(25010)
+    assert arctic._obis.empty is False
+    assert len(arctic.all_species) > 0
 
 
 def test_readers():
     """
     test data readers for different stored datasets
+
+    This does not test the reading of the IUCN GISD and Red-List data.
+    These files can not be added to the data we re-distribute, tests
+    are included in the manual integration_evaluation.py
     """
     ecomrgidlink = readers.eco_mrgid_link()
     assert isinstance(ecomrgidlink, pd.DataFrame)
     assert len(ecomrgidlink) > 0
 
-    taxonomy = readers.read_taxonomy()
-    assert isinstance(taxonomy, pd.DataFrame)
-    assert "species" in taxonomy.columns
-    assert len(taxonomy) > 0
-
-    gisd = readers.read_gisd()
-    assert isinstance(gisd, pd.DataFrame)
-    assert len(gisd) > 0
-
     natcon = readers.read_natcon()
     assert isinstance(natcon, pd.DataFrame)
     assert len(natcon) > 0
@@ -93,18 +108,7 @@ def test_ecoregions_plot():
     the plot calls should not cause any error
     """
 
-    ml.plot(eco_code=20002)
+    ml.plot(eco_code=20002, show=False)
 
     species = ml.Species(145634)
-    species.plot()
-
-
-def test_big_region_obis_api():
-    """
-    the obis API calls has issue with big region.
-    It needs special code and this test is to make
-    sure all big regions will run properly.
-    Here we use High Arctic Archipelago (code 25010)
-    """
-    arctic = ml.MarineLife(25010)
-    assert arctic.obis.empty is False
+    species.plot(show=False)
